import version
import argparse
import inapps
import build
import os
from project import Project
import fileutils


def console():
    main()


def _version():
    print version.__version__


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('-p', type=str, help='Path to project root', default='')
    parser.add_argument('-t', type=str, help='Command', default='build')
    parser.add_argument('-c', type=str, help='Build configuration (debug, release, pre-release', default='debug')
    parser.add_argument('-platform', type=str, help='Build platform (windows, android, ios. (in-future: steam, os-x)', default='android')
    parser.add_argument('-build_version', type=str, help='Build version. Can be 0 (current build version)', default='0')
    args = parser.parse_args()

    command = args.t

    fileutils.root_dir = args.p
    if not os.path.isdir(fileutils.root_dir):
        print 'Invalid path to project [{}]'.format(args.p)
        exit(-1)

    if command == 'init':
        project = Project(empty=True)
        project.create()
        exit(0)

    Project.instance = Project()

    if command == 'inapps':
        inapps.run(Project.instance.package,
                   Project.instance.name,
                   Project.instance.version,
                   Project.instance.gg_inapps)
    elif command == 'build':
        configuration = args.c
        platform = args.platform
        build_version = args.build_version
        build.run(platform,
                  configuration,
                  Project.instance.package,
                  Project.instance.version,
                  build_version)
    else:
        print 'Unknown command [{}]'.format(command)


if __name__ == '__main__':
    main()



import os
import xml.etree.ElementTree as ET
import fileutils


ConfigurationDebug = 0
ConfigurationRelease = 1
ConfigurationPreRelease = 2


class PlatformWindow:

    def get_configuration_name(self, configuration):
        strs = ['GameDebug', 'Release', 'GameRelease']
        return strs[configuration]

    def set_version(self, packagename, app_version, build_version):
        pass

    def build(self, configuration):
        cmd = 'msbuild "{}/../../SyndicateBase/proj.win32/SyndicateBase.sln" /p:Configuration={} /p:Platform=win32 /m'. \
            format(fileutils.root_dir, self.get_configuration_name(configuration))
        result = os.system(cmd)
        print 'Finished with code', result
        return result


class PlatformAndroid:

    def build(self, configuration):
        tasks = ['assembleDebug', 'assembleRelease', 'assembleRelease']
        task = tasks[configuration]
        cmd = 'gradle {} -p {}/proj.android'.format(task, fileutils.root_dir)
        result = os.system(cmd)
        print 'Finished with code', result
        return result

    def set_version(self, packagename, app_version, build_version):
        path = fileutils.root_dir + '/proj.android/app/AndroidManifest.xml'
        ET.register_namespace('android', 'http://schemas.android.com/apk/res/android')
        with open(path, 'r') as handle:
            tree = ET.parse(handle)
            if build_version:
                tree.getroot().attrib["{http://schemas.android.com/apk/res/android}versionCode"] = str(build_version)
            tree.getroot().attrib["{http://schemas.android.com/apk/res/android}versionName"] = '{}.{}'.format(app_version, build_version)
            tree.getroot().attrib["package"] = packagename
            tree.write(path, encoding='utf-8', xml_declaration=True)


def run(platform, configuration, package_name, app_version, build_version=None):
    platforms = {'windows': PlatformWindow, 'android': PlatformAndroid, 'ios': PlatformWindow}
    configurations = {'debug': ConfigurationDebug, 'release': ConfigurationRelease, 'pre-release': ConfigurationPreRelease, }

    build = platforms[platform]()
    configuration = configurations[configuration]

    build.set_version(package_name, app_version, build_version)
    build.build(configuration)


if __name__ == '__main__':
    run('android', 'debug', 'com.stereo7games.syndicate3', '1.0', '1')
